@@ -89,7 +89,7 @@ struct _GeditAppPrivate
 static gboolean new_window = FALSE;
 static gboolean new_document = FALSE;
 static gchar *geometry = NULL;
-static const GeditEncoding *encoding = NULL;
+static const GtkSourceEncoding *encoding = NULL;
 static GInputStream *stdin_stream = NULL;
 static GSList *file_list = NULL;
 static gint line_position = 0;
@@ -185,6 +185,7 @@ gedit_app_dispose (GObject *object)
 	g_clear_object (&app->priv->window_menu);
 	g_clear_object (&app->priv->notebook_menu);
 	g_clear_object (&app->priv->tab_width_menu);
+	g_clear_object (&app->priv->line_col_menu);
 
 	G_OBJECT_CLASS (gedit_app_parent_class)->dispose (object);
 }
@@ -421,6 +422,74 @@ load_accels (void)
 	}
 }
 
+static gpointer
+get_builder_object_ref (GtkBuilder  *builder,
+                        const gchar *name)
+{
+	gpointer ret;
+
+	ret = gtk_builder_get_object (builder, name);
+
+	if (ret != NULL)
+	{
+		g_object_ref_sink (ret);
+	}
+
+	return ret;
+}
+
+static void
+theme_changed (GtkSettings *settings,
+	       GParamSpec  *pspec,
+	       gpointer     data)
+{
+	static GtkCssProvider *provider;
+
+	if (pspec == NULL || g_str_equal (pspec->name, "gtk-theme-name"))
+	{
+		gchar *theme;
+		GdkScreen *screen;
+
+		g_object_get (settings, "gtk-theme-name", &theme, NULL);
+		screen = gdk_screen_get_default ();
+
+		if (g_str_equal (theme, "Adwaita"))
+		{
+			if (provider == NULL)
+			{
+				GFile *file;
+
+				provider = gtk_css_provider_new ();
+				file = g_file_new_for_uri ("resource:///org/gnome/gedit/ui/gedit.adwaita.css");
+				gtk_css_provider_load_from_file (provider, file, NULL);
+				g_object_unref (file);
+			}
+
+			gtk_style_context_add_provider_for_screen (screen,
+								   GTK_STYLE_PROVIDER (provider),
+								   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+		}
+		else if (provider != NULL)
+		{
+			gtk_style_context_remove_provider_for_screen (screen,
+								      GTK_STYLE_PROVIDER (provider));
+			g_clear_object (&provider);
+		}
+
+		g_free (theme);
+	}
+}
+
+static void
+setup_theme_extensions (void)
+{
+	GtkSettings *settings;
+
+	settings = gtk_settings_get_default ();
+	g_signal_connect (settings, "notify", G_CALLBACK (theme_changed), NULL);
+	theme_changed (settings, NULL, NULL);
+}
+
 static void
 gedit_app_startup (GApplication *application)
 {
@@ -458,6 +527,8 @@ gedit_app_startup (GApplication *application)
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (), icon_dir);
 	g_free (icon_dir);
 
+        setup_theme_extensions ();
+
 #ifndef ENABLE_GVFS_METADATA
 	gedit_metadata_manager_init ();
 #endif
@@ -493,16 +564,16 @@ gedit_app_startup (GApplication *application)
 			appmenu = G_MENU_MODEL (gtk_builder_get_object (builder, "appmenu"));
 			gtk_application_set_app_menu (GTK_APPLICATION (application), appmenu);
 
-			app->priv->window_menu = G_MENU_MODEL (gtk_builder_get_object (builder, "gear_menu_withappmenu"));
+			app->priv->window_menu = G_MENU_MODEL (get_builder_object_ref (builder, "gear_menu_withappmenu"));
 		}
 		else
 		{
-			app->priv->window_menu = G_MENU_MODEL (gtk_builder_get_object (builder, "gear_menu_noappmenu"));
+			app->priv->window_menu = G_MENU_MODEL (get_builder_object_ref (builder, "gear_menu_noappmenu"));
 		}
 
-		app->priv->notebook_menu = G_MENU_MODEL (gtk_builder_get_object (builder, "notebook_menu"));
-		app->priv->tab_width_menu = G_MENU_MODEL (gtk_builder_get_object (builder, "tab_width_menu"));
-		app->priv->line_col_menu = G_MENU_MODEL (gtk_builder_get_object (builder, "line_col_menu"));
+		app->priv->notebook_menu = G_MENU_MODEL (get_builder_object_ref (builder, "notebook_menu"));
+		app->priv->tab_width_menu = G_MENU_MODEL (get_builder_object_ref (builder, "tab_width_menu"));
+		app->priv->line_col_menu = G_MENU_MODEL (get_builder_object_ref (builder, "line_col_menu"));
 	}
 
 	g_object_unref (builder);
@@ -855,7 +926,7 @@ gedit_app_command_line (GApplication            *application,
 
 	if (g_variant_dict_lookup (options, "encoding", "&s", &encoding_charset))
 	{
-		encoding = gedit_encoding_get_from_charset (encoding_charset);
+		encoding = gtk_source_encoding_get_from_charset (encoding_charset);
 
 		if (encoding == NULL)
 		{
@@ -910,6 +981,13 @@ gedit_app_command_line (GApplication            *application,
 	return 0;
 }
 
+static void
+encoding_foreach_cb (const GtkSourceEncoding *encoding,
+		     gpointer                 user_data)
+{
+	g_print ("%s\n", gtk_source_encoding_get_charset (encoding));
+}
+
 static gint
 gedit_app_handle_local_options (GApplication *application,
                                 GVariantDict *options)
@@ -922,16 +1000,7 @@ gedit_app_handle_local_options (GApplication *application,
 
 	if (g_variant_dict_contains (options, "list-encodings"))
 	{
-		gint i = 0;
-		const GeditEncoding *enc;
-
-		while ((enc = gedit_encoding_get_from_index (i)) != NULL)
-		{
-			g_print ("%s\n", gedit_encoding_get_charset (enc));
-
-			++i;
-		}
-
+		gtk_source_encoding_foreach (encoding_foreach_cb, NULL);
 		return 0;
 	}
 
