@@ -24,8 +24,6 @@
 #include <config.h>
 #endif
 
-#include <string.h> /* For strlen and strcmp */
-
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
@@ -75,21 +73,17 @@ get_tab_from_file (GList *docs,
 	while (docs != NULL)
 	{
 		GeditDocument *d;
+		GtkSourceFile *source_file;
 		GFile *l;
 
 		d = GEDIT_DOCUMENT (docs->data);
+		source_file = gedit_document_get_file (d);
 
-		l = gedit_document_get_location (d);
-		if (l != NULL)
+		l = gtk_source_file_get_location (source_file);
+		if (l != NULL && g_file_equal (l, file))
 		{
-			if (g_file_equal (l, file))
-			{
-				tab = gedit_tab_get_from_document (d);
-				g_object_unref (l);
-				break;
-			}
-
-			g_object_unref (l);
+			tab = gedit_tab_get_from_document (d);
+			break;
 		}
 
 		docs = g_list_next (docs);
@@ -115,12 +109,12 @@ is_duplicated_file (GSList *files,
 
 /* File loading */
 static GSList *
-load_file_list (GeditWindow         *window,
-		const GSList        *files,
-		const GeditEncoding *encoding,
-		gint                 line_pos,
-		gint                 column_pos,
-		gboolean             create)
+load_file_list (GeditWindow             *window,
+		const GSList            *files,
+		const GtkSourceEncoding *encoding,
+		gint                     line_pos,
+		gint                     column_pos,
+		gboolean                 create)
 {
 	GeditTab *tab;
 	GSList *loaded_files = NULL; /* Number of files to load */
@@ -284,18 +278,18 @@ load_file_list (GeditWindow         *window,
  * gedit_commands_load_location:
  * @window: a #GeditWindow
  * @location: a #GFile to be loaded
- * @encoding: (allow-none): the #GeditEncoding of @location
+ * @encoding: (allow-none): the #GtkSourceEncoding of @location
  * @line_pos: the line position to place the cursor when @location is loaded
  * @column_pos: the line column to place the cursor when @location is loaded
  *
  * Loads @location. Ignores non-existing locations
  */
 void
-gedit_commands_load_location (GeditWindow         *window,
-			      GFile               *location,
-			      const GeditEncoding *encoding,
-			      gint                 line_pos,
-			      gint                 column_pos)
+gedit_commands_load_location (GeditWindow             *window,
+			      GFile                   *location,
+			      const GtkSourceEncoding *encoding,
+			      gint                     line_pos,
+			      gint                     column_pos)
 {
 	GSList *locations = NULL;
 	gchar *uri;
@@ -321,7 +315,7 @@ gedit_commands_load_location (GeditWindow         *window,
  * gedit_commands_load_locations:
  * @window: a #GeditWindow
  * @locations: (element-type Gio.File): the locations to be loaded
- * @encoding: (allow-none): the #GeditEncoding of @location
+ * @encoding: (allow-none): the #GtkSourceEncoding of @location
  * @line_pos: the line position to place the cursor when @location is loaded
  * @column_pos: the line column to place the cursor when @location is loaded
  *
@@ -330,11 +324,11 @@ gedit_commands_load_location (GeditWindow         *window,
  * Returns: (element-type Gedit.Document) (transfer container): the locations that were loaded
  */
 GSList *
-gedit_commands_load_locations (GeditWindow         *window,
-			       const GSList        *locations,
-			       const GeditEncoding *encoding,
-			       gint                 line_pos,
-			       gint                 column_pos)
+gedit_commands_load_locations (GeditWindow             *window,
+			       const GSList            *locations,
+			       const GtkSourceEncoding *encoding,
+			       gint                     line_pos,
+			       gint                     column_pos)
 {
 	g_return_val_if_fail (GEDIT_IS_WINDOW (window), 0);
 	g_return_val_if_fail ((locations != NULL) && (locations->data != NULL), 0);
@@ -350,11 +344,11 @@ gedit_commands_load_locations (GeditWindow         *window,
  * titled document.
  */
 GSList *
-_gedit_cmd_load_files_from_prompt (GeditWindow         *window,
-				   GSList              *files,
-				   const GeditEncoding *encoding,
-				   gint                 line_pos,
-				   gint                 column_pos)
+_gedit_cmd_load_files_from_prompt (GeditWindow             *window,
+				   GSList                  *files,
+				   const GtkSourceEncoding *encoding,
+				   gint                     line_pos,
+				   gint                     column_pos)
 {
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -378,7 +372,7 @@ open_dialog_response_cb (GeditFileChooserDialog *dialog,
                          GeditWindow            *window)
 {
 	GSList *files;
-	const GeditEncoding *encoding;
+	const GtkSourceEncoding *encoding;
 	GSList *loaded;
 
 	gedit_debug (DEBUG_COMMANDS);
@@ -434,6 +428,9 @@ _gedit_cmd_file_open (GSimpleAction *action,
 		return;
 	}
 
+	gtk_widget_hide (GTK_WIDGET (window->priv->open_document_popover));
+	gtk_widget_hide (GTK_WIDGET (window->priv->fullscreen_open_document_popover));
+
 	/* Translators: "Open" is the title of the file chooser window */
 	open_dialog = gedit_file_chooser_dialog_new (_("Open"),
 						     GTK_WINDOW (window),
@@ -455,14 +452,12 @@ _gedit_cmd_file_open (GSimpleAction *action,
 	doc = gedit_window_get_active_document (window);
 	if (doc != NULL)
 	{
-		GFile *file;
+		GtkSourceFile *file = gedit_document_get_file (doc);
+		GFile *location = gtk_source_file_get_location (file);
 
-		file = gedit_document_get_location (doc);
-
-		if (file != NULL)
+		if (location != NULL)
 		{
-			default_path = g_file_get_parent (file);
-			g_object_unref (file);
+			default_path = g_file_get_parent (location);
 		}
 	}
 
@@ -655,12 +650,12 @@ change_compression (GtkWindow *parent,
 	return (ret == GTK_RESPONSE_YES);
 }
 
-static GeditDocumentCompressionType
+static GtkSourceCompressionType
 get_compression_type_from_file (GFile *file)
 {
 	gchar *name;
 	gchar *content_type;
-	GeditDocumentCompressionType type;
+	GtkSourceCompressionType type;
 
 	name = g_file_get_basename (file);
 	content_type = g_content_type_guess (name, NULL, 0, NULL);
@@ -696,31 +691,33 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 
 	if (tab != NULL)
 	{
-		GFile *file;
+		GFile *location;
 		GeditDocument *doc;
+		GtkSourceFile *file;
 		gchar *parse_name;
-		GeditDocumentNewlineType newline_type;
-		GeditDocumentCompressionType compression_type;
-		GeditDocumentCompressionType current_compression_type;
-		const GeditEncoding *encoding;
+		GtkSourceNewlineType newline_type;
+		GtkSourceCompressionType compression_type;
+		GtkSourceCompressionType current_compression_type;
+		const GtkSourceEncoding *encoding;
 
 		doc = gedit_tab_get_document (tab);
+		file = gedit_document_get_file (doc);
 
-		file = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (dialog));
-		g_return_if_fail (file != NULL);
+		location = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (dialog));
+		g_return_if_fail (location != NULL);
 
-		compression_type = get_compression_type_from_file (file);
-		current_compression_type = gedit_document_get_compression_type (doc);
+		compression_type = get_compression_type_from_file (location);
+		current_compression_type = gtk_source_file_get_compression_type (file);
 
-		if ((compression_type == GEDIT_DOCUMENT_COMPRESSION_TYPE_NONE) !=
-		    (current_compression_type == GEDIT_DOCUMENT_COMPRESSION_TYPE_NONE))
+		if ((compression_type == GTK_SOURCE_COMPRESSION_TYPE_NONE) !=
+		    (current_compression_type == GTK_SOURCE_COMPRESSION_TYPE_NONE))
 		{
 			if (!change_compression (GTK_WINDOW (dialog),
-			                         file,
-			                         compression_type != GEDIT_DOCUMENT_COMPRESSION_TYPE_NONE))
+			                         location,
+			                         compression_type != GTK_SOURCE_COMPRESSION_TYPE_NONE))
 			{
 				gtk_widget_destroy (GTK_WIDGET (dialog));
-				g_object_unref (file);
+				g_object_unref (location);
 
 				goto save_next_tab;
 			}
@@ -734,7 +731,7 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 		doc = gedit_tab_get_document (tab);
 		g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
 
-		parse_name = g_file_get_parse_name (file);
+		parse_name = g_file_get_parse_name (location);
 
 		gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
 					        window->priv->generic_message_cid,
@@ -745,11 +742,11 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 
 		/* let's remember the dir we navigated too,
 		 * even if the saving fails... */
-		 _gedit_window_set_default_location (window, file);
+		_gedit_window_set_default_location (window, location);
 
-		_gedit_tab_save_as (tab, file, encoding, newline_type, compression_type);
+		_gedit_tab_save_as (tab, location, encoding, newline_type, compression_type);
 
-		g_object_unref (file);
+		g_object_unref (location);
 	}
 
 save_next_tab:
@@ -833,9 +830,10 @@ _gedit_cmd_file_save_as_tab (GeditTab    *tab,
 	GtkWidget *save_dialog;
 	GtkWindowGroup *wg;
 	GeditDocument *doc;
-	GFile *file;
-	const GeditEncoding *encoding;
-	GeditDocumentNewlineType newline_type;
+	GtkSourceFile *file;
+	GFile *location;
+	const GtkSourceEncoding *encoding;
+	GtkSourceNewlineType newline_type;
 
 	g_return_if_fail (GEDIT_IS_TAB (tab));
 	g_return_if_fail (GEDIT_IS_WINDOW (window));
@@ -859,23 +857,21 @@ _gedit_cmd_file_save_as_tab (GeditTab    *tab,
 
 	wg = gedit_window_get_group (window);
 
-	gtk_window_group_add_window (wg,
-				     GTK_WINDOW (save_dialog));
+	gtk_window_group_add_window (wg, GTK_WINDOW (save_dialog));
 
 	/* Save As dialog is modal to its main window */
 	gtk_window_set_modal (GTK_WINDOW (save_dialog), TRUE);
 
 	/* Set the suggested file name */
 	doc = gedit_tab_get_document (tab);
-	file = gedit_document_get_location (doc);
+	file = gedit_document_get_file (doc);
+	location = gtk_source_file_get_location (file);
 
-	if (file != NULL)
+	if (location != NULL)
 	{
 		gtk_file_chooser_set_file (GTK_FILE_CHOOSER (save_dialog),
-					   file,
+					   location,
 					   NULL);
-
-		g_object_unref (file);
 	}
 	else
 	{
@@ -904,10 +900,10 @@ _gedit_cmd_file_save_as_tab (GeditTab    *tab,
 	}
 
 	/* Set suggested encoding */
-	encoding = gedit_document_get_encoding (doc);
+	encoding = gtk_source_file_get_encoding (file);
 	g_return_if_fail (encoding != NULL);
 
-	newline_type = gedit_document_get_newline_type (doc);
+	newline_type = gtk_source_file_get_newline_type (file);
 
 	gedit_file_chooser_dialog_set_encoding (GEDIT_FILE_CHOOSER_DIALOG (save_dialog),
 						encoding);
