@@ -72,6 +72,8 @@ void		 gedit_statusbar_flash_message		(GeditStatusbar   *statusbar,
 							 const gchar      *format,
 							 ...) G_GNUC_PRINTF(3, 4);
 
+void _gedit_statusbar_line_col_button_set_visible	(GeditStatusbar *statusbar,
+                                                         gboolean        visible);
 G_END_DECLS
 
 #endif
