@@ -26,7 +26,6 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <atk/atk.h>
-#include <gedit/gedit-encodings.h>
 #include <gedit/gedit-document.h>
 #include <gtksourceview/gtksource.h>
 
@@ -124,12 +123,17 @@ gboolean	 gedit_utils_decode_uri 		(const gchar      *uri,
 /* Turns data from a drop into a list of well formatted uris */
 gchar		**gedit_utils_drop_get_uris		(GtkSelectionData *selection_data);
 
-GeditDocumentCompressionType
+GtkSourceCompressionType
 		 gedit_utils_get_compression_type_from_content_type
 		 					(const gchar      *content_type);
 
 gchar           *gedit_utils_set_direct_save_filename	(GdkDragContext *context);
 
+/* Private */
+GSList		*_gedit_utils_encoding_strv_to_list	(const gchar * const *enc_str);
+
+gchar	       **_gedit_utils_encoding_list_to_strv	(const GSList *enc_list);
+
 G_END_DECLS
 
 #endif /* __GEDIT_UTILS_H__ */
