@@ -21,7 +21,9 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
+
 #include <glib.h>
+
 #include "gedit-app.h"
 #ifdef OS_OSX
 #include "gedit-app-osx.h"
@@ -33,6 +35,8 @@
 #endif
 #endif
 
+#include "gedit-debug.h"
+
 #ifdef G_OS_WIN32
 #include <gmodule.h>
 static GModule *libgedit_dll = NULL;
@@ -40,8 +44,8 @@ static GModule *libgedit_dll = NULL;
 /* This code must live in gedit.exe, not in libgedit.dll, since the whole
  * point is to find and load libgedit.dll.
  */
-static void
-gedit_w32_load_private_dll (GType *type)
+static gboolean
+gedit_w32_load_private_dll (void)
 {
 	gchar *dllpath;
 	gchar *prefix;
@@ -69,13 +73,7 @@ gedit_w32_load_private_dll (GType *type)
 		libgedit_dll = g_module_open ("libgedit.dll", 0);
 	}
 
-	if (libgedit_dll != NULL)
-	{
-		/* Now that we did everything we could to make the DLL available, we can
-		 * implicitly call the *_get_type() function from it.
-		 */
-		*type = GEDIT_TYPE_APP_WIN32;
-	}
+	return (libgedit_dll != NULL);
 }
 
 static void
@@ -100,7 +98,13 @@ main (int argc, char *argv[])
 	type = GEDIT_TYPE_APP_OSX;
 #else
 #ifdef G_OS_WIN32
-	gedit_w32_load_private_dll (&type);
+	if (!gedit_w32_load_private_dll ())
+	{
+		g_printerr ("Failed to load libgedit DLL\n");
+		return 1;
+	}
+
+	type = GEDIT_TYPE_APP_WIN32;
 #else
 	type = GEDIT_TYPE_APP_X11;
 #endif
@@ -113,8 +117,20 @@ main (int argc, char *argv[])
 
 	status = g_application_run (G_APPLICATION (app), argc, argv);
 
+	/* Break reference cycles caused by the PeasExtensionSet
+	 * for GeditAppActivatable which holds a ref on the GeditApp
+	 */
+	g_object_run_dispose (G_OBJECT (app));
+
+	g_object_add_weak_pointer (G_OBJECT (app), (gpointer *) &app);
 	g_object_unref (app);
 
+	if (app != NULL)
+	{
+		gedit_debug_message (DEBUG_APP, "Leaking with %i refs",
+		                     G_OBJECT (app)->ref_count);
+	}
+
 #ifdef G_OS_WIN32
 	gedit_w32_unload_private_dll ();
 #endif
